==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/de/modules.php <==
<?php
return array (
  '%moduleName% - Set as default module' => '%moduleName% - Als Standard festlegen',
  '<strong>Module</strong> details' => '<strong>Modul</strong>-Informationen',
  'Activated' => 'Aktiviert',
  'Always activated' => 'Immer aktiviert',
  'Are you sure? *ALL* module data will be lost!' => 'Bist du sicher? *ALLE* Modul Daten gehen verloren!',
  'Are you sure? *ALL* module related data and files will be lost!' => 'Bist du sicher? *ALLE* Modul-abhängigen Daten und Dateien gehen verloren!',
  'Close' => 'Schließen',
  'Configure' => 'Konfigurieren',
  'Could not find requested module!' => 'Kann gesuchtes Modul nicht finden!',
  'Deactivated' => 'Deaktivieren',
  'Disable' => 'Deaktivieren',
  'Enable' => 'Aktivieren',
  'Enable module...' => 'Modul aktivieren ...',
  'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Hier kannst du entscheiden ob ein Modul automatisch innerhalb eines Space oder in einem Benutzerprofil aktiviert sein soll oder nicht. Soll das Modul immer aktiviert sein, wähle "Immer aktiviert".',
  'Legacy' => 'Legacy',
  'License not found or expired. Please contact the module publisher.' => 'Lizenz nicht gefunden oder abgelaufen. Bitte Herausgeber des Moduls kontaktieren.',
  'Module path %path% is not writeable!' => 'Modul Verzeichnis %path% ist nicht beschreibbar!',
  'Modules extend the functionality of HumHub. Here you can install and manage modules from the HumHub Marketplace.' => 'Module erweitern die Funktionen von HumHub. Hier kannst du Module aus dem Marktplatz installieren und verwalten.',
  'More info' => 'Mehr Informationen',
  'No modules installed yet. Install some to enhance the functionality!' => 'Aktuell sind keine Module installiert. Installiere welche und erweitere so die Funktionen von HumHub!',
  'Not maintained or maintenance is about to be discontinued.' => 'Wird nicht gewartet oder die Wartung wird demnächst eingestellt.',
  'Save' => 'Speichern',
  'Set as default' => 'Standard festlegen',
  'Spaces' => 'Spaces',
  'This module doesn\'t provide further information.' => 'Dieses Modul liefert keine weiteren Informationen.',
  'Uninstall' => 'Deinstallieren',
  'User Profiles' => 'Benutzerprofile',
  'Version:' => 'Version:',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/de/modules.php <==
<?php
return array (
  '%moduleName% - Set as default module' => '%moduleName% - Als Standard festlegen',
  '<strong>General</strong> Settings' => '<strong>Allgemeine</strong> Einstellungen',
  '<strong>Module</strong> details' => '<strong>Modul</strong>-Informationen',
  'Activate' => 'Aktivieren',
  'Activated' => 'Aktiviert',
  'Allow module versions in beta status' => 'Modulversionen im Beta-Status zulassen',
  'Always activated' => 'Immer aktiviert',
  'Are you sure? *ALL* module data will be lost!' => 'Bist du sicher? *ALLE* Modul Daten gehen verloren!',
  'Are you sure? *ALL* module related data and files will be lost!' => 'Bist du sicher? *ALLE* Modul-abhängigen Daten und Dateien gehen verloren!',
  'Close' => 'Schließen',
  'Configure' => 'Konfigurieren',
  'Could not find requested module!' => 'Kann gesuchtes Modul nicht finden!',
  'Deactivated' => 'Deaktivieren',
  'Deprecated' => 'Veraltet',
  'Enable module...' => 'Modul aktivieren ...',
  'Featured' => 'Empfohlen',
  'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Hier kannst du entscheiden ob ein Modul automatisch innerhalb eines Space oder in einem Benutzerprofil aktiviert sein soll oder nicht. Soll das Modul immer aktiviert sein, wähle "Immer aktiviert".',
  'Installed' => 'Installiert',
  'License not found or expired. Please contact the module publisher.' => 'Lizenz nicht gefunden oder abgelaufen. Bitte Herausgeber des Moduls kontaktieren.',
  'Module "{moduleName}" has been updated to version {newVersion} successfully.' => 'Module "{moduleName}" wurde erfolgreich auf die Version {newVersion} aktualisiert.',
  'Module path %path% is not writeable!' => 'Modul Verzeichnis %path% ist nicht beschreibbar!',
  'New' => 'Neu',
  'No modules found.' => 'Keine Module gefunden.',
  'Not Installed' => 'Nicht installiert',
  'Official' => 'Offiziell',
  'Partner' => 'Partner',
  'Professional Edition' => 'Professional Edition',
  'Save' => 'Speichern',
  'Space default state' => 'Space Standard Einstellung',
  'Spaces' => 'Spaces',
  'This module doesn\'t provide further information.' => 'Dieses Modul liefert keine weiteren Informationen.',
  'Try other keywords or remove filters.' => 'Versuche andere Suchbegriffe oder reduziere Filter.',
  'Update successful' => 'Aktualisierung erfolgreich!',
  'User default state' => 'Profil Standard Einstellung',
  'Users' => 'Benutzer',
);
